<?php
$fevr_purchase_key = fevr_purchase_key();

// Hide menus and functions on subsites. True if should show, false if should hide
$ms_restriction = (!defined('MULTISITE') || MULTISITE !== true || get_current_blog_id() == BLOG_ID_CURRENT_SITE || current_user_can('manage_network_themes'));

// Show purge CDN if MaxCDN is set
$maxcdn = (fevr_check_luvoption('enable-cdn', 1) && fevr_check_luvoption('maxcdn-alias', '','!=') && fevr_check_luvoption('maxcdn-key', '','!=') && fevr_check_luvoption('maxcdn-secret', '','!='));

// Show clear cache if merge scripts/styles are enabled
$merge_assets = (fevr_check_luvoption('merge-styles', 1) || fevr_check_luvoption('merge-scripts', 1));

// Prepare tabs
$tabs = array(
		'dashboard' => esc_html__('Dashboard', 'fevr'),
		'activate' => empty($fevr_purchase_key) ? esc_html__('Activate', 'fevr') : null,
		'performance' => ($merge_assets || $maxcdn ? esc_html__('Performance', 'fevr') : ''),
		'fevr-mobile' => fevr_check_luvoption('enable-mobile-app', 1) && !empty($fevr_purchase_key) ? esc_html__('Fevr Mobile', 'fevr') : null,
		'support' => esc_html__('Support', 'fevr'),
);

// Remove support tab if whitelabel mode is active
if (defined('FEVR_WHITELABEL')){
	unset($tabs['support']);
}

// Select active tab
$active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'dashboard';

// Manually check updates
if (isset($_GET['check-luv-updates'])){
	fevr_update_checker();
}

// Run update
if (isset($_GET['luv-updater'])){
	if (isset($_REQUEST['_wpnonce']) && wp_verify_nonce( $_REQUEST['_wpnonce'], 'fevr-update' ) && current_user_can('manage_options') && $ms_restriction){
		include_once trailingslashit(get_template_directory()) . 'luvthemes/includes/updater.inc.php';

		$updater = new Fevr_Updater($fevr_purchase_key);
		try {
			if ($updater->update()){
				fevr_print_admin_notice(array('class' => 'success', 'message' =>esc_html__('Theme sucessfully updated', 'fevr')));
			}
		} catch (Exception $e) {
			fevr_print_admin_notice(array('class' => 'error', 'message' => $e->getMessage()));
		}
	}
}

// Requirements
$memory_limit = ini_get('memory_limit');
if (preg_match('~M$~i', $memory_limit)){
	$memory_limit = (int)$memory_limit * 1024 * 1024;
}
else if (preg_match('~G$~i', $memory_limit)){
	$memory_limit = (int)$memory_limit * 1024 * 1024 * 1024;
}

$max_input_vars = ini_get('max_input_vars');

$requirements = array(
	'luvthemes_core'	=> (defined('LUVTHEMES_CORE_VER') ? true : false),
	'memory_limit'	=> ($memory_limit >= 64 * 1024 * 1024 ? true : false),
	'max_input_vars'	=> ($max_input_vars >= 2000 ? true : false),
	'php_version'	=> version_compare(phpversion(), '5.3', '>=')
);

?>

<div class="wrap luv-dashboard-wrap">
	<div class="luv-content-area">
		<div class="luv-dashboard-logo"><img src="//fevr.luvthemes.com/images/fevr_version.png"></div>
		<?php if (empty($fevr_purchase_key)):?>
		<h1><?php echo sprintf(esc_html__('Welcome to %s!', 'fevr'), FEVR_THEME_NAME); ?></h1>
		<div class="luv-page-dashboard-desc">
			<?php echo sprintf(fevr_kses(__('<strong>Congratulations!</strong><br> %s is now installed. Please register your product to enable automatic theme updates and support. If you need help, please feel free to contact us at', 'fevr')), FEVR_THEME_NAME); ?> <a href="mailto:support@luvthemes.com">support@luvthemes.com</a>

			<form method="post" class="luv-dashboard-activate">
				<input type="text" name="envato-purchase-key" value="<?php echo esc_attr($fevr_purchase_key);?>">
				<input type="hidden" name="luv-save-settings" value="purchase-key">
				<?php wp_nonce_field( 'fevr-save-settings', 'luv-nonce')?>
				<button class="luv-btn luv-btn-green"><?php esc_html_e('Activate', 'fevr')?></button>
			</form>
			<p><small><?php esc_html_e('A purchase key is only valid for a single domain. Would you like to use the theme on a new domain?', 'fevr'); ?> <a href="http://themeforest.net/item/fevr-responsive-multipurpose-wordpress-theme/14051111?license=regular&open_purchase_for_item_id=14051111&purchasable=source&ref=luvthemes" target="_blank"><?php esc_html_e('Get a new license here.', 'fevr'); ?></a></small></p>
		</div>
		<?php else:?>
		<h1><?php echo sprintf(esc_html__('%s Dashboard', 'fevr'), FEVR_THEME_NAME); ?></h1>
		<div class="luv-page-dashboard-desc">
			<?php echo sprintf(fevr_kses(__('<strong>Congratulations!</strong> Fevr is registered on', 'fevr')), FEVR_THEME_NAME); ?> <u><?php echo preg_replace('~https?://~','',home_url());?></u>. <?php esc_html_e('Simply click to the button to remove the purchase key from this website.', 'fevr')?></a>
			<form method="post" class="luv-dashboard-activate">
				<input type="text" name="envato-purchase-key" value="<?php echo esc_attr($fevr_purchase_key);?>" readonly>
				<input type="hidden" name="luv-save-settings" value="remove-purchase-key">
				<?php wp_nonce_field( 'fevr-save-settings', 'luv-nonce')?>
				<button class="luv-btn luv-btn-red"><?php esc_html_e('Remove Purchase Key', 'fevr')?></button>
			</form>
			<p><small><?php esc_html_e('A purchase key is only valid for a single domain. Would you like to use the theme on a new domain?', 'fevr'); ?> <a href="http://themeforest.net/item/fevr-responsive-multipurpose-wordpress-theme/14051111?license=regular&open_purchase_for_item_id=14051111&purchasable=source&ref=luvthemes" target="_blank"><?php esc_html_e('Get a new license here.', 'fevr'); ?></a></small></p>
		</div>
		<?php endif?>
	</div>
<!--
	<h2 class="nav-tab-wrapper">
	<?php foreach($tabs as $key=>$tab):
	  if (empty($tab)){
	  	continue;
	  }
	 ?>
	 <a href="<?php echo esc_url(add_query_arg('tab', $key, menu_page_url('fevr-dashboard', false)));?>" class="nav-tab <?php echo ($key == $active_tab ? 'nav-tab-active' : '');?>"><?php echo esc_html($tab)?></a>
	 <?php endforeach;?>
	</h2>
-->

	<?php
	//Activate
	if ($active_tab == 'activate' && empty($fevr_purchase_key) && $ms_restriction):?>
			<h4><?php esc_html_e('Add your Envato purchase key', 'fevr')?></h4>
			<form method="post">
				<input type="text" name="envato-purchase-key" value="<?php echo esc_attr($fevr_purchase_key);?>">
				<input type="hidden" name="luv-save-settings" value="purchase-key">
				<?php wp_nonce_field( 'fevr-save-settings', 'luv-nonce')?>
				<button class="luv-btn luv-btn-green"><?php esc_html_e('Save', 'fevr')?></button>
			</form>
	<?php
	//Support
	elseif ($active_tab == 'support'):?>
		<h4><?php esc_html_e('Do you have a question? Chat with us!', 'fevr')?></h4>
		<strong>support@luvthemes.com</strong>
	<?php
	//Support
	elseif ($active_tab == 'performance'):?>
		<?php if($merge_assets):?>
			<h4><?php esc_html_e('Theme Cache', 'fevr')?></h4>
			<span><?php esc_html_e('With this option you can clear the merged scripts/styles cache.', 'fevr')?></span>
			<div class="luv-dashboard-section">
				<a class="luv-btn luv-btn-blue" href="<?php echo esc_url(wp_nonce_url(add_query_arg('clear-luv-cache', 1, site_url(str_replace(site_url(), '', 'http'.(isset($_SERVER['HTTPS']) ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']))), 'clear-luv-cache'))?>"><?php esc_html_e('Clear Theme Cache', 'fevr')?></a>
			</div>
		<?php endif;?>
		<?php if($maxcdn):?>
			<h4><?php esc_html_e('Purge CDN', 'fevr')?></h4>
			<form method="post">
				<div class="luv-dashboard-section">
					<button class="luv-btn luv-btn-red"><?php esc_html_e('Purge CDN', 'fevr')?></button>
				</div>
				<div class="luv-dashboard-section">
				<?php
					$maxcdn_api = new Fevr_MaxCDN(fevr_get_luvoption('maxcdn-alias'),fevr_get_luvoption('maxcdn-key'),fevr_get_luvoption('maxcdn-secret'));
					$response = json_decode($maxcdn_api->get('/zones.json'),true);
				?>
				<?php if ($response['code'] == '200'):?>
					<select name="zone-id">
					<?php foreach ($response['data']['zones'] as $zone):?>
						<option value="<?php echo esc_attr($zone['id'])?>"><?php echo esc_html($zone['name'])?> (<?php echo esc_attr($zone['id'])?>)</option>
					<?php endforeach;?>
					</select>
				<?php endif;?>
				<input type="hidden" name="purge-fevr-cdn" value="1">
				<?php wp_nonce_field('purge-fevr-cdn')?>
				</div>
			</form>
		<?php endif;?>
	<?php
	//Support
	elseif ($active_tab == 'fevr-mobile'):?>
		<?php $fevr_mobile_data = fevr_get_fevr_mobile_data();?>
		<?php if (!empty($fevr_mobile_data['link'])):?>
		<div class="luv-dashboard-row">
			<div class="luv-dashboard-col">
				<h4><?php esc_html_e('Download App', 'fevr')?></h4>
				<a href="<?php echo esc_url($fevr_mobile_data['link'])?>" target="_blank" class="luv-btn luv-btn-blue"><?php esc_html_e('Download Zip', 'fevr')?> (v<?php echo esc_html($fevr_mobile_data['app_version'])?>)</a>
				<a href="https://build.phonegap.com/" target="_blank" class="luv-btn luv-btn-green"><?php esc_html_e('Build with PhoneGap', 'fevr')?></a>
			</div>
			<div class="luv-dashboard-col">
				<h4><?php esc_html_e('Android Key', 'fevr')?></h4>
				<a href="<?php echo esc_url($fevr_mobile_data['keystore'])?>" target="_blank" class="luv-btn luv-btn-blue"><?php esc_html_e('Download Android Key File', 'fevr')?></a><br><br>
				<div class="luv-dashboard-info">
					<strong><?php esc_html_e('Android Key Alias:','fevr')?></strong> fevr<br>
					<strong><?php esc_html_e('Certificate Password:','fevr')?></strong> <?php echo esc_html($fevr_mobile_data['keystore_password']);?><br>
					<strong><?php esc_html_e('Keystore Password:','fevr')?></strong> <?php echo esc_html($fevr_mobile_data['keystore_password']);?><br>
				</div>
			</div>
		</div>
		<?php endif;?>
		<h4><?php echo sprintf(esc_html__('Generate %s Mobile App', 'fevr'), FEVR_THEME_NAME);?></h4>
		<form method="post">
			<div class="luv-meta-field-section">
				<label><?php esc_html_e('Author E-mail', 'fevr');?></label>
				<div class="luv-meta-field-container">
					<input type="text" name="author_email" value="<?php echo esc_attr(isset($fevr_mobile_data['author_email']) ? $fevr_mobile_data['author_email'] : get_option('admin_email'));?>">
				</div>
			</div>
			<div class="luv-meta-field-section">
				<label><?php esc_html_e('Author Web', 'fevr');?></label>
				<div class="luv-meta-field-container">
					<input type="text" name="author_web" value="<?php echo esc_url(isset($fevr_mobile_data['author_web']) ? $fevr_mobile_data['author_web'] : trailingslashit(site_url()))?>">
				</div>
			</div>
			<div class="luv-meta-field-section">
				<label><?php esc_html_e('App Icon', 'fevr');?></label>
				<div class="luv-meta-field-container">
					<div class="luv-media-upload-container media-image">
						<input type="hidden" name="icon" class="luv-media-upload-url" value="<?php echo esc_url(isset($fevr_mobile_data['icon']) ? $fevr_mobile_data['icon'] : '')?>">
						<img src="<?php echo esc_url(isset($fevr_mobile_data['icon']) ? $fevr_mobile_data['icon'] : '')?>" class="luv-media-upload-preview <?php echo (isset($fevr_mobile_data['icon']) && !empty($fevr_mobile_data['icon']) ? '' : 'is-hidden') ?>">
						<div class="luv-media-buttons">
							<span class="button media_upload_button luv-media-upload"><?php echo (isset($fevr_mobile_data['icon']) && !empty($fevr_mobile_data['icon']) ? esc_html__('Modify', 'fevr') : esc_html__('Upload', 'fevr'));?></span>
							<span class="button remove-image luv-media-upload-reset <?php echo (isset($fevr_mobile_data['icon']) && !empty($fevr_mobile_data['icon']) ? '' : 'is-hidden') ?>">Remove</span>
						</div>
					</div>
				</div>
			</div>
			<div class="luv-meta-field-section">
				<label><?php esc_html_e('App Version', 'fevr');?></label>
				<div class="luv-meta-field-container">
					<input type="text" name="app_version" value="<?php echo esc_attr(isset($fevr_mobile_data['app_version']) ? $fevr_mobile_data['app_version'] : '1.0');?>">
				</div>
			</div>
			<div class="luv-meta-field-section">
				<label><?php esc_html_e('App Name', 'fevr');?></label>
				<div class="luv-meta-field-container">
					<input type="text" name="app_name" value="<?php echo esc_attr(isset($fevr_mobile_data['app_name']) ? $fevr_mobile_data['app_name'] : get_bloginfo('name'));?>">
				</div>
			</div>
			<div class="luv-meta-field-section">
				<label><?php esc_html_e('App Description', 'fevr');?></label>
				<div class="luv-meta-field-container">
					<input type="text" name="app_description" value="<?php echo esc_attr(isset($fevr_mobile_data['app_description']) ? $fevr_mobile_data['app_description'] : '');?>">
				</div>
			</div>
			<div class="luv-meta-field-section">
				<button class="luv-btn luv-btn-green luv-generate-mobile-app"><?php esc_html_e('Generate', 'fevr')?></button>
			</div>
			<input type="hidden" name="generate-fevr-mobile" value="generate">
			<?php wp_nonce_field( 'fevr-generate-mobile-app', 'luv-nonce')?>
		</form>
	<?php
	//Dashboard
	else:
		$update_info = get_option('fevr_update',array());

		$installer_info = get_option('fevr_installer',array());
	?>

		<div class="luv-dashboard-container">
			<div class="luv-dashboard-row">
				<?php if (!defined('FEVR_WHITELABEL')):?>
				<div class="luv-dashboard-col">
					<h4><?php esc_html_e('Demo Content', 'fevr')?></h4>
					<div class="luv-dashboard-col-content">
						<p><?php esc_html_e('Install demo content with a single click!', 'fevr'); ?> <br> <?php esc_html_e('If you would like to install only specific pages then click', 'fevr'); ?> <a href="<?php echo get_admin_url(); ?>edit.php?post_type=page&page=fevr_use_template"><?php esc_html_e('here.', 'fevr'); ?></a></p>
						<a class="luv-btn luv-btn-blue" href="<?php echo esc_url(FEVR_LUVINSTALLER_INSTALLER_URL);?>"><?php echo (isset($installer_info['scheme']) && !empty($installer_info['scheme'])) ? esc_html__('Continue install', 'fevr') : esc_html__('Install demo content', 'fevr')?></a>
					</div>
				</div>
				<?php endif;?>
				<?php if($ms_restriction):?>
				<div class="luv-dashboard-col">
					<h4><?php esc_html_e('Updates', 'fevr')?></h4>
					<div class="luv-dashboard-col-content">
						<p>
							<strong><?php esc_html_e('Installed Version', 'fevr'); ?></strong><br> <?php echo esc_html(FEVR_THEME_VER); ?><br>
							<?php if (isset($update_info['version'])):?>
								<strong><?php esc_html_e('Latest Available Version', 'fevr'); ?></strong><br> <?php echo esc_html($update_info['version']);?> (<a href="http://docs.luvthemes.com/changelog/#<?php echo esc_attr($update_info['version'])?>" target="_blank"><?php esc_html_e('changelog', 'fevr'); ?></a>)<br>
							<?php endif;?>
						</p>
						<?php if (!empty($update_info) && version_compare(FEVR_THEME_VER, $update_info['version'], '<')):?>
							<p><?php echo FEVR_THEME_NAME . ' ' . $update_info['version'] . esc_html__(' is available! Please update now.', 'fevr')?></p>
							<a class="luv-btn luv-btn-green" href="<?php echo esc_url(add_query_arg( array('luv-updater' => '1', 'tab' => 'dashboard'), wp_nonce_url(menu_page_url('fevr-dashboard', false), 'fevr-update')));?>"><?php esc_html_e('Update now', 'fevr')?></a>
						<?php else:?>
							<?php if (isset($_GET['check-luv-updates'])):?>
							<p><?php echo sprintf(esc_html__('You are already using the latest version of %s', 'fevr'), FEVR_THEME_NAME);?></p>
							<?php endif;?>
							<a class="luv-btn luv-btn-green" href="<?php echo  esc_url(add_query_arg( array('check-luv-updates' => '1', 'tab' => 'dashboard'), menu_page_url('fevr-dashboard', false)));?>"><?php esc_html_e('Check for updates', 'fevr')?></a>
						<?php endif;?>
					</div>
				</div>
				<?php endif;?>
				<div class="luv-dashboard-col">
					<h4><?php esc_html_e('System Requirements', 'fevr'); ?></h4>
					<div class="luv-dashboard-col-content">
						<ul class="luv-system-requirements">
							<li class="luv-status-<?php echo ($requirements['luvthemes_core'] ? 'green' : 'red');?>"><span class="luv-status-title"><?php esc_html_e('Luvthemes Core Active', 'fevr'); ?></span> <span><?php echo ($requirements['luvthemes_core'] ? esc_html__('Yes', 'fevr') : esc_html__('No', 'fevr')); ?></span></li>
							<li class="luv-status-<?php echo ($requirements['memory_limit'] ? 'green' : 'red');?>"><span class="luv-status-title"><?php esc_html_e('Memory Limit', 'fevr'); ?></span> <span><?php echo ((int)$memory_limit/1024/1024)?>M</span></li>
							<li class="luv-status-<?php echo ($requirements['max_input_vars'] ? 'green' : 'red');?>"><span class="luv-status-title"><?php esc_html_e('Max Input Vars', 'fevr'); ?></span> <span><?php echo (int)$max_input_vars?></span></li>
							<li class="luv-status-<?php echo ($requirements['php_version'] ? 'green' : 'red');?>"><span class="luv-status-title"><?php esc_html_e('PHP Version', 'fevr'); ?></span> <span><?php echo phpversion()?></span></li>
						</ul>
					</div>
				</div>
			</div>
			<div class="luv-dashboard-row">
				<div class="luv-dashboard-col">
					<h4><?php esc_html_e('Theme Support', 'fevr'); ?></h4>
					<div class="luv-dashboard-col-content">
						<ul>
							<li><i class="fa fa-book"></i> <a href="http://docs.luvthemes.com/" target="_blank"><?php esc_html_e('Documentation', 'fevr'); ?></a></li>
							<li><i class="fa fa-support"></i> <a href="http://support.luvthemes.com/" target="_blank"><?php esc_html_e('Support', 'fevr'); ?></a></li>
							<li><i class="fa fa-vimeo"></i> <a href="https://vimeo.com/luvthemes" target="_blank"><?php esc_html_e('Video Tutorials', 'fevr'); ?></a></li>
							<li><i class="fa fa-leaf"></i> <a href="http://themeforest.net/user/luvthemes/follow" target="_blank"><?php esc_html_e('Follow us on Envato', 'fevr'); ?></a></li>
						</ul>



						<p class="luv-text-small"><?php esc_html_e('Fevr comes with 6 months (extendable to 12 months) item support from purchase date. The item support DOES NOT include customization services and support for non-bundled party plugins.', 'fevr'); ?> <a href="https://themeforest.net/page/item_support_policy" target="_blank">(<?php esc_html_e('more..', 'fevr'); ?>)</a> <?php esc_html_e('For customization services please contact us at', 'fevr'); ?> <a href="mailto:support@luvthemes.com">support@luvthemes.com</a>.</p>
					</div>
				</div>
<!--
				<div class="luv-dashboard-col">
					<h4><?php esc_html_e('Luvthemes News', 'fevr'); ?></h4>
					<div class="luv-dashboard-col-content">

					</div>
				</div>
-->
			</div>
		</div>
	<?php endif;?>
</div>
