<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product, $woocommerce_loop, $fevr_options, $fevr_wc_animation, $fevr_wc_carousel, $fevr_is_wc_masonry, $fevr_is_wc_masonry_automatic_metro, $fevr_masonry_size_overrides;

// Global animation
if (isset($fevr_options['woocommerce-animation']) && !empty($fevr_options['woocommerce-animation']) && !fevr_is_luv_shortcode()){
	$fevr_wc_animation = $fevr_options['woocommerce-animation'];
}

// Store loop count we're currently on
if ( empty( $woocommerce_loop['loop'] ) ) {
	$woocommerce_loop['loop'] = 0;
}

// Store column count for displaying the grid
if ( empty( $woocommerce_loop['columns'] ) ) {
	$woocommerce_loop['columns'] = apply_filters( 'loop_shop_columns', 4 );
}

// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}

// Increase loop count
$woocommerce_loop['loop']++;

// Extra post classes
$classes = array();
if ( 0 === ( $woocommerce_loop['loop'] - 1 ) % $woocommerce_loop['columns'] || 1 === $woocommerce_loop['columns'] ) {
	$classes[] = 'first';
}
if ( 0 === $woocommerce_loop['loop'] % $woocommerce_loop['columns'] ) {
	$classes[] = 'last';
}

// Animation
if (!empty($fevr_wc_animation)){
	$classes[] = 'c-has-animation';
	$classes[] = $fevr_wc_animation;
}

if (!empty($fevr_wc_carousel)){
	$classes[] = fevr_enqueue_inline_css(array('parent' => '.woocommerce .products li', 'style' => 'width:unset;'));
}

if ($fevr_is_wc_masonry === true){
	global $fevr_wc_masonry_product_size;
	$masonry_size = get_post_meta(get_the_ID(), '_product_masonry_size', true);
	$masonry_size = (!empty($masonry_size) ? $masonry_size : 'fevr_normal');
	$fevr_wc_masonry_product_size = ($fevr_is_wc_masonry_automatic_metro && !empty($fevr_masonry_size_overrides[get_the_ID()]) ? $fevr_masonry_size_overrides[get_the_ID()] : 'fevr_normal');

	$classes[] = 'masonry-size-' . $fevr_wc_masonry_product_size;
}

$classes[] = 'product';

?>
<li <?php wc_product_class( '', $product ); ?>>
	<?php
	/**
	 * Hook: woocommerce_before_shop_loop_item.
	 *
	 * @hooked woocommerce_template_loop_product_link_open - 10
	 */
	do_action( 'woocommerce_before_shop_loop_item' );

	/**
	 * Hook: woocommerce_before_shop_loop_item_title.
	 *
	 * @hooked woocommerce_show_product_loop_sale_flash - 10
	 * @hooked woocommerce_template_loop_product_thumbnail - 10
	 */
	do_action( 'woocommerce_before_shop_loop_item_title' );

	/**
	 * Hook: woocommerce_shop_loop_item_title.
	 *
	 * @hooked woocommerce_template_loop_product_title - 10
	 */
	do_action( 'woocommerce_shop_loop_item_title' );

	/**
	 * Hook: woocommerce_after_shop_loop_item_title.
	 *
	 * @hooked woocommerce_template_loop_rating - 5
	 * @hooked woocommerce_template_loop_price - 10
	 */
	do_action( 'woocommerce_after_shop_loop_item_title' );

	/**
	 * Hook: woocommerce_after_shop_loop_item.
	 *
	 * @hooked woocommerce_template_loop_product_link_close - 5
	 * @hooked woocommerce_template_loop_add_to_cart - 10
	 */
	do_action( 'woocommerce_after_shop_loop_item' );
	?>
</li>
