<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @package 	WooCommerce/Templates
 * @version     3.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}

?>
<form  class="woocommerce-form woocommerce-form-login login l-grid-row" method="post" <?php echo ( $hidden ) ? 'style="display:none;"' : ''; ?>>
	<div class="l-grid-4">
		<?php do_action( 'woocommerce_login_form_start' ); ?>
	
		<?php echo ( $message ) ? wpautop( wptexturize( $message ) ) : ''; // @codingStandardsIgnoreLine ?>
	
		<p class="form-row form-row-first">
			<label for="username"><?php echo esc_html(fevr__w( 'Username or email', 'fevr', 'woocommerce' )); ?> <span class="required">*</span></label>
			<input type="text" class="input-text" name="username" id="username" autocomplete="username" />
		</p>
		<p class="form-row form-row-last">
			<label for="password"><?php echo esc_html(fevr__w( 'Password', 'fevr', 'woocommerce' )); ?> <span class="required">*</span></label>
			<input class="input-text" type="password" name="password" id="password" autocomplete="current-password" />
		</p>
		<div class="clear"></div>
	
		<?php do_action( 'woocommerce_login_form' ); ?>
	
		<p class="form-row">
			<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
			<button type="submit" class="woocommerce-button woocommerce-form-login__submit button btn btn-global btn-uppercase btn-full" name="login" value="<?php esc_attr_e( 'Login', 'woocommerce' ); ?>"><?php echo esc_html(fevr__w( 'Login', 'fevr', 'woocommerce' )); ?></button></p>
			<input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ) ?>" />
			<label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme inline">
				<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" /> <span><?php echo esc_html(fevr__w( 'Remember me', 'fevr', 'woocommerce' )); ?></span>
			</label>
		</p>
		<p class="lost_password">
			<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php echo esc_html(fevr__w( 'Lost your password?', 'fevr', 'woocommerce' )); ?></a>
		</p>
	
		<div class="clear"></div>
	
		<?php do_action( 'woocommerce_login_form_end' ); ?>
	</div>
</form>