<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 4.3.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
	<div id="comments">
		<h2 class="woocommerce-Reviews-title">
			<?php
			$count = $product->get_review_count();
			if ( $count && wc_review_ratings_enabled() ) {
				/* translators: 1: reviews count 2: product name */
				$reviews_title = sprintf( esc_html( fevr_n( '%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'fevr', 'woocommerce' ) ), esc_html( $count ), '<span>' . get_the_title() . '</span>' );
				echo apply_filters( 'woocommerce_reviews_title', $reviews_title, $count, $product ); // WPCS: XSS ok.
			} else {
				fevr_ew( 'Reviews', 'fevr', 'woocommerce' );
			}
			?>
		</h2>

		<?php if ( have_comments() ) : ?>
			<ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ol>

			<?php
			if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links(
					apply_filters(
						'woocommerce_comment_pagination_args',
						array(
							'prev_text' => '&larr;',
							'next_text' => '&rarr;',
							'type'      => 'list',
						)
					)
				);
				echo '</nav>';
			endif;
			?>
		<?php else : ?>
			<p class="woocommerce-noreviews"><?php fevr_ew( 'There are no reviews yet.', 'fevr', 'woocommerce' ); ?></p>
		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>
		<div id="review_form_wrapper">
			<div id="review_form">
				<?php
				$commenter = wp_get_current_commenter();

				$comment_form = array(
					'title_reply'          => have_comments() ? fevr__w( 'Add a review', 'fevr', 'woocommerce' ) : fevr__w( 'Be the first to review', 'fevr', 'woocommerce' ) . ' &ldquo;' . get_the_title() . '&rdquo;',
					'title_reply_to'       => fevr__w( 'Leave a Reply to %s', 'fevr', 'woocommerce' ),
					'title_reply_after'	   => '</h3>'.fevr_get_woocommerce_photo_review_button(),
					'comment_notes_before' => '',
					'comment_notes_after'  => '',
					'class_submit'      => 'submit btn btn-global btn-full',
					'label_submit'  => fevr__w( 'Submit', 'fevr', 'woocommerce' ),
					'logged_in_as'  => '',
					'comment_field' => ''
				);

				$name_email_required = (bool) get_option( 'require_name_email', 1 );
				$fields              = array(
					'author' => array(
						'label'    => fevr__w( 'Name', 'fevr', 'woocommerce' ),
						'type'     => 'text',
						'value'    => $commenter['comment_author'],
						'required' => $name_email_required,
					),
					'email'  => array(
						'label'    => fevr__w( 'Email', 'fevr', 'woocommerce' ),
						'type'     => 'email',
						'value'    => $commenter['comment_author_email'],
						'required' => $name_email_required,
					),
				);

				$comment_form['fields'] = array();

				foreach ( $fields as $key => $field ) {
					$field_html  = '<p class="comment-form-' . esc_attr( $key ) . '">';
					$field_html .= '<label for="' . esc_attr( $key ) . '">' . esc_html( $field['label'] );

					if ( $field['required'] ) {
						$field_html .= '&nbsp;<span class="required">*</span>';
					}

					$field_html .= '</label><input id="' . esc_attr( $key ) . '" name="' . esc_attr( $key ) . '" type="' . esc_attr( $field['type'] ) . '" value="' . esc_attr( $field['value'] ) . '" size="30" ' . ( $field['required'] ? 'required' : '' ) . ' /></p>';

					$comment_form['fields'][ $key ] = $field_html;
				}

				$account_page_url = wc_get_page_permalink( 'myaccount' );
				if ( $account_page_url ) {
					/* translators: %s opening and closing link tags respectively */
					$comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf( fevr__w( 'You must be <a href="%s">logged in</a> to post a review.', 'fevr', 'woocommerce' ), '<a href="' . esc_url( $account_page_url ) . '">', '</a>' ) . '</p>';
				}

				if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' && wc_review_ratings_enabled() ) {
					$comment_form['comment_field'] = '<div class="comment-form-rating"><label for="rating">' . fevr__w( 'Your rating', 'fevr', 'woocommerce' ) .'</label><select name="rating" id="rating">
							<option value="">' . fevr__w( 'Rate&hellip;', 'fevr', 'woocommerce' ) . '</option>
							<option value="5">' . fevr__w( 'Perfect', 'fevr', 'woocommerce' ) . '</option>
							<option value="4">' . fevr__w( 'Good', 'fevr', 'woocommerce' ) . '</option>
							<option value="3">' . fevr__w( 'Average', 'fevr', 'woocommerce' ) . '</option>
							<option value="2">' . fevr__w( 'Not that bad', 'fevr', 'woocommerce' ) . '</option>
							<option value="1">' . fevr__w( 'Very poor', 'fevr', 'woocommerce' ) . '</option>
						</select></div>';
				}

				$comment_form['comment_field'] .= '<p class="comment-form-comment"><label for="comment">' . fevr__w( 'Your review', 'fevr', 'woocommerce' ) . '&nbsp;<span class="required">*</span></label><textarea id="comment" name="comment" cols="45" rows="8" required></textarea></p>';

				comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
			</div>
		</div>
	<?php else : ?>
		<p class="woocommerce-verification-required"><?php fevr_ew( 'Only logged in customers who have purchased this product may leave a review.', 'fevr', 'woocommerce' ); ?></p>
	<?php endif; ?>

	<div class="clear"></div>
</div>
